==> wevue-2.8.1.tgz: package/lib/package.js <==
var Wxss = require('./wxss');
var path = require('path');
var fs = require('fs');
var debug = require('debug')('wevue');

module.exports = function(wxFolder, vueFolder, rootFolder, wevueFolder, program) {

  var envs = program.env || [];
  if (program.env && program.env.length > 0) {
    var env = "WEVUE_ENV=" + JSON.stringify(program.env);
    envs.push(env);
  }

  if (program.server && program.server !== true) {
    var server = "SERVER=" + program.server;
    envs.push(server);
  }

  if (program.port && program.port !== true) {
    var port = "PORT=" + program.port;
    envs.push(port);
  }

  if (program.path && program.path !== true) {
    var distPath = program.path;
    if (distPath && distPath.substr(distPath.length - 1) != '/') {
      distPath = '/' + distPath;
    }
    distPath = "DIST_PATH=" + distPath;
    envs.push(distPath);
  } else {
    if (process.env.DIST_PATH) {
      var distPath = process.env.DIST_PATH;
      if (distPath && distPath.substr(distPath.length - 1) != '/') {
        distPath = '/' + distPath;
      }
      distPath = "DIST_PATH=" + distPath;
      envs.push(distPath);
    }
  }

  var packageJson = path.join(wevueFolder, program.wevue, 'package.json');
  var destPackageJson = path.join(vueFolder, 'package.json');

  debug('packageJson', packageJson);
  debug('destPackageJson', destPackageJson);

  if (fs.existsSync(packageJson)) {
    debug('replace');
    var packageContent = fs.readFileSync(packageJson, 'utf8');
    var packageJSON = JSON.parse(packageContent);
    var template = packageJSON["scripts-template"];

    var envsStr = envs.join(" ");

    packageJSON.scripts["dev"] = template.dev.replace("{{ENVS}}", envsStr);
    packageJSON.scripts["build"] = template.build.replace("{{ENVS}}", envsStr);

    delete packageJSON["scripts-template"];

    content = JSON.stringify(packageJSON, null, 4);
    debug(content);
    fs.writeFileSync(destPackageJson, content);
  }
}

==> wevue-2.8.2.tgz: package/lib/package.js <==
var Wxss = require('./wxss');
var path = require('path');
var fs = require('fs');
var debug = require('debug')('wevue');

module.exports = function(wxFolder, vueFolder, rootFolder, wevueFolder, program) {

  var envs = program.env || [];
  if (program.env && program.env.length > 0) {
    var env = "WEVUE_ENV=" + JSON.stringify(program.env);
    envs.push(env);
  }

  if (program.server && program.server !== true) {
    var server = "SERVER=" + program.server;
    envs.push(server);
  }

  if (program.port && program.port !== true) {
    var port = "PORT=" + program.port;
    envs.push(port);
  }

  if (program.path && program.path !== true) {
    var distPath = program.path;
    if (distPath && distPath.substr(distPath.length - 1) != '/') {
      distPath = '/' + distPath;
    }
    distPath = "DIST_PATH=" + distPath;
    envs.push(distPath);
  } else {
    if (process.env.DIST_PATH) {
      var distPath = process.env.DIST_PATH;
      if (distPath && distPath.substr(distPath.length - 1) != '/') {
        distPath = '/' + distPath;
      }
      distPath = "DIST_PATH=" + distPath;
      envs.push(distPath);
    }
  }

  var packageJson = path.join(wevueFolder, program.wevue, 'package.json');
  var destPackageJson = path.join(vueFolder, 'package.json');

  debug('packageJson', packageJson);
  debug('destPackageJson', destPackageJson);

  if (fs.existsSync(packageJson)) {
    debug('replace');
    var packageContent = fs.readFileSync(packageJson, 'utf8');
    var packageJSON = JSON.parse(packageContent);
    var template = packageJSON["scripts-template"];

    var envsStr = envs.join(" ");

    packageJSON.scripts["dev"] = template.dev.replace(/\{\{ENVS\}\}/g, envsStr);
    packageJSON.scripts["build"] = template.build.replace(/\{\{ENVS\}\}/g, envsStr);

    delete packageJSON["scripts-template"];

    content = JSON.stringify(packageJSON, null, 4);
    debug(content);
    fs.writeFileSync(destPackageJson, content);
  }
}
